import { Authorizer } from '@authorizerdev/authorizer-js';
import { Server } from '@hocuspocus/server';

const authorizer = new Authorizer({
  clientID: process.env.AUTHORIZER_CLIENT_ID || '',
  authorizerURL: 'https://auth.discours.io',
  redirectURL: 'https://testing.discours.io',
});

const server = Server.configure({
  port: process.env.PORT || 4000,
  onConnect({ connection }) {
    connection.requiresAuthentication = true;
  },
  onAuthenticate(data) {
    if (data.requestHeaders) {
      const params = {
        token_type: 'access_token',
        token: data.requestHeaders['authorization'] || '',
      };
      if (params.token) {
        authorizer.validateJWTToken(params)
          .then(response => {

          if (response?.data?.is_valid) {
            const { sub: user, allowed_roles: roles } = response.data.claims;
            console.debug(`user_id: ${user} roles: ${roles}`);
            return {
              id: user,
              roles,
            };
          }
        }).catch((e) => {
          console.error(e)
          console.error('no valid auth token presented');
          throw new Error('Not authorized!');
        })
      }
    }
  },
});

server.listen();
